@@ -16,6 +16,7 @@ describe 'heat::db' do
         :max_retries    => '<SERVICE DEFAULT>',
         :retry_interval => '<SERVICE DEFAULT>',
         :max_overflow   => '<SERVICE DEFAULT>',
+        :pool_timeout   => '<SERVICE DEFAULT>',
       )}
 
     end
@@ -30,6 +31,7 @@ describe 'heat::db' do
           :database_retry_interval => '11',
           :database_db_max_retries => '-1',
           :database_max_overflow   => '21',
+          :database_pool_timeout   => '21',
           :sync_db                 => false }
       end
 
@@ -43,6 +45,7 @@ describe 'heat::db' do
         :max_retries    => '11',
         :retry_interval => '11',
         :max_overflow   => '21',
+        :pool_timeout   => '21',
       )}
 
     end
