@@ -139,7 +139,7 @@ describe 'heat::engine' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts())
+        facts.merge!(OSDefaults.get_facts({:os_workers_heat_engine => 2}))
       end
 
       let :platform_params do
