@@ -13,14 +13,14 @@ describe 'heat::keystone::authtoken' do
       it 'configure keystone_authtoken' do
         is_expected.to contain_heat_config('keystone_authtoken/username').with_value('heat')
         is_expected.to contain_heat_config('keystone_authtoken/password').with_value('heat_password')
-        is_expected.to contain_heat_config('keystone_authtoken/auth_url').with_value('http://127.0.0.1:35357/')
+        is_expected.to contain_heat_config('keystone_authtoken/auth_url').with_value('http://127.0.0.1:5000/')
         is_expected.to contain_heat_config('keystone_authtoken/project_name').with_value('services')
         is_expected.to contain_heat_config('keystone_authtoken/user_domain_name').with_value('Default')
         is_expected.to contain_heat_config('keystone_authtoken/project_domain_name').with_value('Default')
         is_expected.to contain_heat_config('keystone_authtoken/insecure').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_heat_config('keystone_authtoken/auth_section').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_heat_config('keystone_authtoken/auth_type').with_value('password')
-        is_expected.to contain_heat_config('keystone_authtoken/auth_uri').with_value('http://127.0.0.1:5000/')
+        is_expected.to contain_heat_config('keystone_authtoken/www_authenticate_uri').with_value('http://127.0.0.1:5000/')
         is_expected.to contain_heat_config('keystone_authtoken/auth_version').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_heat_config('keystone_authtoken/cache').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_heat_config('keystone_authtoken/cafile').with_value('<SERVICE DEFAULT>')
@@ -43,8 +43,6 @@ describe 'heat::keystone::authtoken' do
         is_expected.to contain_heat_config('keystone_authtoken/memcache_use_advanced_pool').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_heat_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_heat_config('keystone_authtoken/region_name').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_heat_config('keystone_authtoken/revocation_cache_time').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_heat_config('keystone_authtoken/signing_dir').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_heat_config('keystone_authtoken/token_cache_time').with_value('<SERVICE DEFAULT>')
       end
     end
@@ -52,10 +50,10 @@ describe 'heat::keystone::authtoken' do
     context 'when overriding parameters' do
       before do
         params.merge!({
-          :auth_uri                             => 'https://10.0.0.1:9999/',
+          :www_authenticate_uri                 => 'https://10.0.0.1:9999/',
           :username                             => 'myuser',
           :password                             => 'mypasswd',
-          :auth_url                             => 'http://:127.0.0.1:35357',
+          :auth_url                             => 'http://:127.0.0.1:5000',
           :project_name                         => 'service_project',
           :user_domain_name                     => 'domainX',
           :project_domain_name                  => 'domainX',
@@ -83,15 +81,14 @@ describe 'heat::keystone::authtoken' do
           :memcache_security_strategy           => 'ENCRYPT',
           :memcache_use_advanced_pool           => true,
           :memcached_servers                    => ['memcached01:11211','memcached02:11211'],
+          :manage_memcache_package              => true,
           :region_name                          => 'region2',
-          :revocation_cache_time                => '11',
-          :signing_dir                          => '/var/cache',
           :token_cache_time                     => '301',
         })
       end
 
       it 'configure keystone_authtoken' do
-        is_expected.to contain_heat_config('keystone_authtoken/auth_uri').with_value('https://10.0.0.1:9999/')
+        is_expected.to contain_heat_config('keystone_authtoken/www_authenticate_uri').with_value('https://10.0.0.1:9999/')
         is_expected.to contain_heat_config('keystone_authtoken/username').with_value(params[:username])
         is_expected.to contain_heat_config('keystone_authtoken/password').with_value(params[:password]).with_secret(true)
         is_expected.to contain_heat_config('keystone_authtoken/auth_url').with_value(params[:auth_url])
@@ -123,10 +120,12 @@ describe 'heat::keystone::authtoken' do
         is_expected.to contain_heat_config('keystone_authtoken/memcache_use_advanced_pool').with_value(params[:memcache_use_advanced_pool])
         is_expected.to contain_heat_config('keystone_authtoken/memcached_servers').with_value('memcached01:11211,memcached02:11211')
         is_expected.to contain_heat_config('keystone_authtoken/region_name').with_value(params[:region_name])
-        is_expected.to contain_heat_config('keystone_authtoken/revocation_cache_time').with_value(params[:revocation_cache_time])
-        is_expected.to contain_heat_config('keystone_authtoken/signing_dir').with_value(params[:signing_dir])
         is_expected.to contain_heat_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
       end
+
+      it 'installs python memcache package' do
+        is_expected.to contain_package('python-memcache')
+      end
     end
   end
 
@@ -138,7 +137,7 @@ describe 'heat::keystone::authtoken' do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      it_configures 'heat authtoken'
+      it_behaves_like 'heat authtoken'
     end
   end
 
